package api

import (
	"errors"
	"fmt"
	"moutai/db/repo"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson"
)

var clickMap = map[string]struct{}{
	repo.CollectionImages: {},
	repo.CollectionVideos: {},
	repo.CollectionRelics: {},
	repo.CollectionVr:     {},
	repo.CollectionAr:     {},
}

func Clicks(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	ClickType := c.Query("type")
	id := c.Query("id")
	if _, ok := clickMap[ClickType]; ok {
		_, err := repo.RepoUpdateSetDocProps(apictx.CreateRepoCtx(), ClickType, id, bson.M{"$inc": bson.M{"clicks": 1}})
		if err != nil {
			return false, err
		}
		return true, nil

	}
	return false, errors.New("参数错误！")

}

func getQuery(query map[string]interface{}) (map[string]interface{}, map[string]interface{}) {
	// query name查询
	if _name, ok := query["name"]; ok {
		name := _name.(string)
		delete(query, "name")
		if len(name) > 0 {
			query["name"] = bson.M{"$regex": name, "$options": "$i"}
		}
	}
	// query uploadTime查询
	if _uploadTime, ok := query["uploadTime"]; ok {
		uploadTime := _uploadTime.(string)
		delete(query, "uploadTime")
		if len(uploadTime) > 0 {
			uploadTime, err := time.Parse("2006-01-02", uploadTime)
			if err == nil {
				startTime := time.Date(uploadTime.Year(), uploadTime.Month(), uploadTime.Day(), 0, 0, 0, 0, uploadTime.Location())
				endTime := time.Date(uploadTime.Year(), uploadTime.Month(), uploadTime.Day(), 23, 59, 59, 0, uploadTime.Location())
				query["createTime"] = bson.M{
					"$gte": startTime,
					"$lte": endTime,
				}
			}
		}
	}

	sortMap := repo.Map{"createTime": -1}
	// query sort查询
	if _sort, ok := query["sort"]; ok {
		// clicks 排序
		if _sort.(string) == "clicks" {
			sortMap = repo.Map{"clicks": -1}
		}
		// sort int自定义排序
		if _sort.(string) == "sort" {
			sortMap = repo.Map{"sort": -1}

		}
		delete(query, "sort")
	}
	fmt.Printf("查询条件:\nquery:%#v\nsortMap: %#v\n", query, sortMap)
	return query, sortMap
}
